.. _urls:

URLS
####

* haloperiodol (haldol) -  https://pubchem.ncbi.nlm.nih.gov/compound/3559#section=Safety-and-Hazards

* clozapine (leponex) - https://pubchem.ncbi.nlm.nih.gov/compound/2818#section=Safety-and-Hazards

* olanzapine (zyprexa) - https://pubchem.ncbi.nlm.nih.gov/compound/4585#section=Safety-and-Hazards

* aripriprazole (abilify) - https://pubchem.ncbi.nlm.nih.gov/compound/60795#section=Safety-and-Hazards

